# Embedding Encoder

::: linax.encoder.embedding.EmbeddingEncoderConfig
    options:
      members:
        - build

---

::: linax.encoder.embedding.EmbeddingEncoder
    options:
      members:
        - __init__
        - __call__
